@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.5.27"
+#define MARIADB_CLIENT_VERSION_STR	"10.5.28"
 #define MARIADB_BASE_VERSION		"mariadb-10.5"
-#define MARIADB_VERSION_ID		100527
+#define MARIADB_VERSION_ID		100528
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100527
-#define MYSQL_SERVER_VERSION            "10.5.27-MariaDB"
+#define MYSQL_VERSION_ID                100528
+#define MYSQL_SERVER_VERSION            "10.5.28-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.25"
-#define MARIADB_PACKAGE_VERSION_ID 30125
+#define MARIADB_PACKAGE_VERSION "3.1.27"
+#define MARIADB_PACKAGE_VERSION_ID 30127
 #define MARIADB_SYSTEM_TYPE "NetBSD"
-#define MARIADB_MACHINE_TYPE "aarch64"
+#define MARIADB_MACHINE_TYPE "aarch64eb"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
