@@ -30,7 +30,7 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
-/* #undef HAVE_FENV_H */
+#define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 /* #undef HAVE_FPU_CONTROL_H */
@@ -41,7 +41,7 @@
 #define HAVE_GETMNTINFO_TAKES_statvfs 1
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
-/* #undef HAVE_IEEEFP_H */
+#define HAVE_IEEEFP_H 1
 #define HAVE_INTTYPES_H 1
 #define HAVE_KQUEUE 1
 #define HAVE_LIMITS_H 1
@@ -140,9 +140,9 @@
 #define HAVE_FCNTL 1
 #define HAVE_FDATASYNC 1
 #define HAVE_DECL_FDATASYNC 1
-/* #undef HAVE_FEDISABLEEXCEPT */
-/* #undef HAVE_FESETROUND */
-/* #undef HAVE_FP_EXCEPT */
+#define HAVE_FEDISABLEEXCEPT 1
+#define HAVE_FESETROUND 1
+#define HAVE_FP_EXCEPT 1
 #define HAVE_FSEEKO 1
 #define HAVE_FSYNC 1
 /* #undef HAVE_FTIME */
@@ -195,6 +195,7 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
+#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -277,10 +278,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define HAVE_LONG 1
@@ -295,7 +296,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -333,7 +334,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -394,8 +395,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "vax"
-#define DEFAULT_MACHINE "vax"
+#define MACHINE_TYPE "aarch64eb"
+#define DEFAULT_MACHINE "aarch64eb"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -531,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 26
+#define MYSQL_VERSION_PATCH 28
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.26"
+#define PACKAGE_STRING "MySQL Server 10.5.28"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.26"
-#define VERSION "10.5.26"
+#define PACKAGE_VERSION "10.5.28"
+#define VERSION "10.5.28"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
