@@ -278,10 +278,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define HAVE_LONG 1
@@ -296,7 +296,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -334,7 +334,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -395,8 +395,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "aarch64"
-#define DEFAULT_MACHINE "aarch64"
+#define MACHINE_TYPE "powerpc"
+#define DEFAULT_MACHINE "powerpc"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -532,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 27
+#define MYSQL_VERSION_PATCH 28
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.27"
+#define PACKAGE_STRING "MySQL Server 10.5.28"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.27"
-#define VERSION "10.5.27"
+#define PACKAGE_VERSION "10.5.28"
+#define VERSION "10.5.28"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
